# $Id: site.bro,v 1.2 2002/10/13 21:07:59 vern Exp $
#
# Definitions describing a site - which networks are "local" and
# and "neighbors".

# class A/B/C networks that are considered "local".
const local_nets: set[net] &redef;

# /16 and /24 addresses (accessed via mask_addr()) corresponding to the above.
const local_16_nets: set[addr] &redef;
const local_24_nets: set[addr] &redef;

# Networks that are considered "neighbors".  Note that unlike
# for local_nets, neighbor_16_nets is *not* merely a /16 addr version
# of neighbor_nets, but instead is consulted *in addition* to neighbor_nets.
const neighbor_nets: set[net] &redef;
const neighbor_16_nets: set[addr] &redef;

# Function that returns true if an address corresponds to one of
# the local networks, false if not.  As currently written, it
# assumes a /16 or a /24, but by adjusting the mask_addr() call
# and/or adding more, it can accommodate a collection of /whatever's.
function is_local_addr(a: addr): bool
	{
	return mask_addr(a, 16) in local_16_nets ||
	       mask_addr(a, 24) in local_24_nets;
	}
